from setuptools import setup, find_packages

setup(
    name= 'jr_pypiexample',
    version= '0.2',
    license= 'MIT',
    description= "paquete de prueba, añadiendo la multiplicación",
    author= "Joserracas",
    author_email= "joserracaswork@gmail.com",
    packages=find_packages(),
    url= 'https://github.com/joserracaswork/jr_pypiexample.git'
    
)